@@ -54,7 +54,7 @@ def replace_location(url):
 		The history.replaceState bit changes what the document.referrer will be on the next page, which is needed for qnc_crud/smart_back_btton.js to work properly.
 
 		TODO - we should either:
-			resolve url relative to current page, as is done in qnc_crud/utils.js in [data-replace-location] handler
+			resolve url relative to current page, as is done in qnc_crud/utils.js in [qnc-replace-location] handler
 			only accept absolute/site-relative urls
 	'''
 	return js_response(f'''
