@@ -218,15 +218,21 @@ $(document).on('keyup', '[qnc-ajax-submit-on-change]', null, function(e) {
     $(document).on('focusin', function(e) {
         // No pop-up open
         if (open_pid === null) return
+
         // Focus remained in pop-up
         if ($(e.target).closest('[qnc-popup]').length > 0) return
 
-        // Close the pop-up
-        // There MAY be a simultaneous click event, which also closes the pop-up
-        // Let the click handler run first, then close (if still necessary)
+        // Focus left the pop-up
+        // There may be a simultaneous click event which will also close this pop-up (and possibly open another)
+        // Make sure that happens before we close this one.
+        // Note - it's surprising how long this delay must be - also, haven't tested in many browsers
+        // I've tried various techniques, and I can't seem to find a way to avoid this timeout
+        var to_close = open_pid
         setTimeout(function() {
-            set_open_pid(null);
-        }, 0);
+            if (open_pid == to_close) {
+                set_open_pid(null);
+            }
+        }, 150);
     });
     // Initialize pop-ups
     var _open = $('[qnc-popup-toggler][aria-expanded]').attr('[qnc-popup-toggler');
